/// <reference types="react" />
import * as yup_lib_types from 'yup/lib/types';
import * as yup from 'yup';
import { AnySchema, StringSchema, NumberSchema, ArraySchema, TestFunction } from 'yup';
import Reference from 'yup/lib/Reference';
import React$1, { MutableRefObject } from 'react';
import { UseFormReturn } from 'react-hook-form';

declare const type: {
    readonly string: "string";
    readonly number: "number";
    readonly bool: "bool";
    readonly date: "date";
    readonly object: "object";
    readonly file: "file";
    readonly json: "json";
};
declare let typeValues: ("string" | "number" | "object" | "bool" | "date" | "file" | "json")[];
declare type Type = typeof typeValues[number];

declare const format: {
    readonly array: "array";
    readonly select: "select";
    readonly code: "code";
    readonly markdown: "markdown";
    readonly text: "textarea";
    readonly textarea: "textarea";
    readonly email: "email";
    readonly password: "password";
    readonly hidden: "hidden";
    readonly form: "form";
    readonly buttonsSelect: "buttons";
    readonly singleLineCode: "singleLineCode";
    readonly datetime: "datetime-local";
    readonly time: "time";
};
declare let formatValues: ("email" | "array" | "select" | "code" | "markdown" | "textarea" | "password" | "hidden" | "form" | "buttons" | "singleLineCode" | "datetime-local" | "time")[];
declare type Format = typeof formatValues[number];

declare type Constraint = (resolver: any, key: string, dependencies: any[]) => AnySchema;
declare type NumberRef = Reference<number> | number;
declare const required: (message?: string) => (r: AnySchema) => any;
declare const url: (message?: string) => (r: StringSchema) => yup.StringSchema<string | undefined, yup_lib_types.AnyObject, string | undefined>;
declare const email: (message?: string) => (r: StringSchema) => yup.StringSchema<string | undefined, yup_lib_types.AnyObject, string | undefined>;
declare const uuid: (message?: string) => (r: StringSchema) => yup.StringSchema<string | undefined, yup_lib_types.AnyObject, string | undefined>;
declare const matches: (regexp?: RegExp, message?: string) => (r: StringSchema) => yup.StringSchema<string | undefined, yup_lib_types.AnyObject, string | undefined>;
declare const min: (ref: NumberRef, message?: string) => (r: StringSchema | NumberSchema) => yup.StringSchema<string | undefined, yup_lib_types.AnyObject, string | undefined> | yup.NumberSchema<number | undefined, yup_lib_types.AnyObject, number | undefined>;
declare const max: (ref: NumberRef, message?: string) => (r: StringSchema | NumberSchema) => yup.StringSchema<string | undefined, yup_lib_types.AnyObject, string | undefined> | yup.NumberSchema<number | undefined, yup_lib_types.AnyObject, number | undefined>;
declare const positive: (message?: string) => (r: NumberSchema) => yup.NumberSchema<number | undefined, yup_lib_types.AnyObject, number | undefined>;
declare const negative: (message?: string) => (r: NumberSchema) => yup.NumberSchema<number | undefined, yup_lib_types.AnyObject, number | undefined>;
declare const integer: (message?: string) => (r: NumberSchema) => yup.NumberSchema<number | undefined, yup_lib_types.AnyObject, number | undefined>;
declare const lessThan: (ref: NumberRef, message?: string) => (r: NumberSchema, key: any, dependencies: Array<[any, Reference]>) => yup.NumberSchema<number | undefined, yup_lib_types.AnyObject, number | undefined>;
declare const moreThan: (ref: NumberRef, message?: string) => (r: NumberSchema, key: any, dependencies: Array<[any, Reference]>) => yup.NumberSchema<number | undefined, yup_lib_types.AnyObject, number | undefined>;
declare const length: (ref: NumberRef, message?: string) => (r: ArraySchema<any>) => yup.ArraySchema<any, yup_lib_types.AnyObject, any[] | undefined, any[] | undefined>;
declare const supportedFormat: (arrayOfValues: string[], message?: string) => (r: AnySchema) => yup.AnySchema<any, any, any>;
declare const unsupportedFormat: (arrayOfValues: string[], message?: string) => (r: AnySchema) => yup.AnySchema<any, any, any>;
declare const maxSize: (ref: Reference, message?: string) => (r: AnySchema) => yup.AnySchema<any, any, any>;
declare const test: (name: string, message: string | undefined, test: TestFunction<any, object>) => (r: AnySchema) => yup.AnySchema<any, any, any>;
declare const when: (ref: string, test: TestFunction<any, object>, then?: Constraint[], otherwise?: Constraint[]) => (r: AnySchema, key: string, dependencies: any[]) => yup.AnySchema<any, any, any>;
declare const oneOf: (arrayOfValues: any[], message?: string) => (r: AnySchema) => yup.AnySchema<any, any, any>;
declare const blacklist: (arrayOfValues: any[], message?: string) => (r: AnySchema) => yup.AnySchema<any, any, any>;
declare const ref: <T>(ref: string) => Reference<T>;
declare const jsonConstraints: Record<string, any>;
declare type TConstraintType = keyof typeof jsonConstraints;

type constraints_d_Constraint = Constraint;
declare const constraints_d_required: typeof required;
declare const constraints_d_url: typeof url;
declare const constraints_d_email: typeof email;
declare const constraints_d_uuid: typeof uuid;
declare const constraints_d_matches: typeof matches;
declare const constraints_d_min: typeof min;
declare const constraints_d_max: typeof max;
declare const constraints_d_positive: typeof positive;
declare const constraints_d_negative: typeof negative;
declare const constraints_d_integer: typeof integer;
declare const constraints_d_lessThan: typeof lessThan;
declare const constraints_d_moreThan: typeof moreThan;
declare const constraints_d_length: typeof length;
declare const constraints_d_supportedFormat: typeof supportedFormat;
declare const constraints_d_unsupportedFormat: typeof unsupportedFormat;
declare const constraints_d_maxSize: typeof maxSize;
declare const constraints_d_test: typeof test;
declare const constraints_d_when: typeof when;
declare const constraints_d_oneOf: typeof oneOf;
declare const constraints_d_blacklist: typeof blacklist;
declare const constraints_d_ref: typeof ref;
declare const constraints_d_jsonConstraints: typeof jsonConstraints;
type constraints_d_TConstraintType = TConstraintType;
declare namespace constraints_d {
  export {
    constraints_d_Constraint as Constraint,
    constraints_d_required as required,
    constraints_d_url as url,
    constraints_d_email as email,
    constraints_d_uuid as uuid,
    constraints_d_matches as matches,
    constraints_d_min as min,
    constraints_d_max as max,
    constraints_d_positive as positive,
    constraints_d_negative as negative,
    constraints_d_integer as integer,
    constraints_d_lessThan as lessThan,
    constraints_d_moreThan as moreThan,
    constraints_d_length as length,
    constraints_d_supportedFormat as supportedFormat,
    constraints_d_unsupportedFormat as unsupportedFormat,
    constraints_d_maxSize as maxSize,
    constraints_d_test as test,
    constraints_d_when as when,
    constraints_d_oneOf as oneOf,
    constraints_d_blacklist as blacklist,
    constraints_d_ref as ref,
    constraints_d_jsonConstraints as jsonConstraints,
    constraints_d_TConstraintType as TConstraintType,
  };
}

interface PropType {
    onChange?: (v: boolean) => void;
    value?: boolean;
    readOnly?: boolean;
    className?: string;
    errorDisplayed?: boolean;
    buttons?: boolean;
    trueLabel?: string;
    falseLabel?: string;
}
declare const BooleanInput: ({ onChange, value, readOnly, className, errorDisplayed, buttons, trueLabel, falseLabel }: PropType) => JSX.Element;

declare const Collapse: (props: {
    initCollapsed?: boolean;
    collapsed?: boolean;
    errored: boolean;
    label?: React$1.ReactNode;
    inline?: any;
    children: React$1.ReactNode;
    lineEnd?: boolean;
}) => JSX.Element;

declare type SelectOption = {
    label: string;
    value: any;
};
declare const SelectInput: <T extends {
    [x: string]: any;
}>(props: {
    possibleValues?: T[] | undefined;
    transformer?: {
        label: string;
        value: string;
    } | ((v: T) => SelectOption) | undefined;
    value?: any;
    defaultValue?: any;
    isMulti?: boolean | undefined;
    optionsFrom?: string | Promise<T[]> | ((param: {
        rawValues: object;
        value: any;
        getValue: (k: string) => any;
    }) => string | Promise<T[]>) | undefined;
    fetchCondition?: (() => boolean) | undefined;
    id?: string | undefined;
    httpClient?: ((url: string, method: string) => Promise<Response>) | undefined;
    onChange?: ((options: any[] | any) => void) | undefined;
    onCreateOption?: ((option: string) => T) | undefined;
    buttons: boolean;
    disabled?: boolean | undefined;
    createOption?: boolean | undefined;
    label?: string | undefined;
    placeholder?: React$1.ReactNode;
    className: string;
    isClearable?: boolean | undefined;
}) => JSX.Element;

declare type InternalState = {
    [x: string]: {
        key: string;
        value: any;
    };
};
declare const ObjectInput: (props: {
    value?: object | undefined;
    onChange?: ((value: InternalState) => void) | undefined;
    defaultKeyValue?: {
        key: string;
        value: string;
    } | undefined;
    className: string;
    disabled?: boolean | undefined;
    placeholderKey?: string | undefined;
    placeholderValue?: string | undefined;
}) => JSX.Element;

declare type LanguageMode = "javascript" | "css" | "json" | "html" | "markdown";

declare function CodeInput({ onChange, value, mode, tabSize, readOnly, showLinesNumber, highlightLine, themeStyle, className, setRef }: {
    onChange?: (v: string) => void;
    value?: string;
    mode?: LanguageMode;
    tabSize?: number;
    readOnly?: boolean;
    showLinesNumber?: boolean;
    highlightLine?: boolean;
    themeStyle?: {
        height: string;
        minHeight: string;
        maxHeight: string;
        width: string;
        minWidth: string;
        maxWidth: string;
    };
    className?: string;
    setRef?: (editor: any) => void;
}): JSX.Element;

declare const MarkdownInput: (props: {
    value?: string | undefined;
    preview?: boolean | undefined;
    className: string;
    readOnly?: boolean | undefined;
    onChange?: ((value: string) => void) | undefined;
    actions?: ((inject: (text: string) => void) => JSX.Element) | undefined;
}) => JSX.Element;

declare function SingleLineCode({ onChange, value, mode, tabSize, readOnly, showLinesNumber, highlightLine, themeStyle }: {
    onChange?: (newValue: string) => void;
    value?: string;
    mode?: LanguageMode;
    tabSize?: number;
    readOnly?: boolean;
    showLinesNumber?: boolean;
    highlightLine?: boolean;
    themeStyle?: {
        height: string;
        minHeight: string;
        maxHeight: string;
        width: string;
        minWidth: string;
        maxWidth: string;
    };
}): JSX.Element;

interface OptionActionItem {
    display?: boolean;
    label?: string;
}
interface OptionActions {
    reset?: OptionActionItem;
    cancel?: OptionActionItem & {
        action: () => void;
    };
    submit?: OptionActionItem;
    add?: OptionActionItem;
}
declare type HttpClient = (url: string, method: string) => Promise<Response>;
interface Option {
    httpClient?: HttpClient;
    watch?: boolean | ((param: any) => void);
    autosubmit?: boolean;
    actions?: OptionActions;
    showErrorsOnStart?: boolean;
}
interface Schema {
    [key: string]: SchemaEntry;
}
declare type SchemaRenderType = ({ rawValues, value, onChange, error, setValue, getValue, informations, defaultValue }: {
    rawValues?: any;
    value?: any;
    onChange?: (param: any) => void;
    error?: boolean;
    getValue: (entry: string) => any;
    informations?: Informations;
    setValue?: (key: string, data: any) => void;
    defaultValue?: any;
}) => JSX.Element;
interface ConditionnalSchemaElement {
    default?: boolean;
    condition?: ({ rawValues, ref }: {
        rawValues: {
            [x: string]: any;
        };
        ref: any;
    }) => boolean | any;
    schema: Schema;
    flow: Array<FlowObject | string>;
}
interface ConditionnalSchema {
    ref: string;
    switch: ConditionnalSchemaElement[];
}
interface SchemaEntry {
    schema?: Schema;
    type: Type;
    format?: Format;
    array?: boolean;
    optional?: boolean;
    createOption?: boolean;
    onCreateOption?: (option: string) => any;
    isMulti?: boolean;
    defaultKeyValue?: object;
    visible?: boolean | ((prop: {
        rawValues: {
            [x: string]: any;
        };
        value: any;
        informations?: Informations;
    }) => boolean);
    disabled?: boolean | ((prop: {
        rawValues: {
            [x: string]: any;
        };
        value: any;
        informations?: Informations;
    }) => boolean);
    label?: React.ReactNode | ((prop: {
        rawValues: {
            [x: string]: any;
        };
        value: any;
        informations?: Informations;
    }) => React.ReactNode);
    placeholder?: string;
    defaultValue?: any;
    help?: string;
    className?: string;
    style?: object;
    onChange?: (params: {
        rawValues: object;
        setValue: (entry: string, value: any) => void;
        value: any;
    }) => void;
    render?: SchemaRenderType;
    itemRender?: SchemaRenderType;
    props?: object;
    options?: Array<any | {
        label: string;
        value: any;
    }>;
    optionsFrom?: string | ((param: {
        rawValues: object;
        value: any;
    }) => Promise<any[]> | string) | Promise<any[]>;
    transformer?: ((v: any) => SelectOption) | {
        label: string;
        value: string;
    };
    conditionalSchema?: ConditionnalSchema;
    constraints?: Array<Constraint | {
        type: TConstraintType;
        message?: string;
    }>;
    arrayConstraints?: Array<Constraint | {
        type: TConstraintType;
        message?: string;
    }>;
    flow?: Array<string | FlowObject>;
    onAfterChange?: (obj: {
        entry: string;
        value: object;
        rawValues: object;
        previousValue?: object;
        getValue: (entry: string) => any;
        setValue: (entry: string, value: any) => void;
        onChange: (v: any) => void;
        reset: (v: any) => void;
        informations?: Informations;
    }) => void;
    visibleOnCollapse?: boolean;
    addableDefaultValue?: any;
    collapsed?: boolean;
    collapsable?: boolean | ((param: {
        rawValues: {
            [x: string]: any;
        };
        value: any;
        getValue: (key: string) => any;
    }) => JSX.Element);
    deps?: string | Array<string> | ((informations: Informations) => string | Array<string>);
    item?: ({
        disabled?: boolean | ((prop: {
            rawValues: {
                [x: string]: any;
            };
            value: any;
            informations?: Informations;
        }) => boolean);
        visible?: boolean | ((prop: {
            rawValues: {
                [x: string]: any;
            };
            value: any;
            informations?: Informations;
        }) => boolean);
        label?: React.ReactNode | ((prop: {
            rawValues: {
                [x: string]: any;
            };
            value: any;
            informations?: Informations;
        }) => React.ReactNode);
        onChange?: (param: object) => void;
        onAfterChange?: (obj: {
            entry: string;
            value: object;
            rawValues: object;
            previousValue?: object;
            getValue: (entry: string) => any;
            setValue: (entry: string, value: any) => void;
            onChange: (v: any) => void;
            informations?: Informations;
        }) => void;
        render?: SchemaRenderType;
        array?: boolean;
        deps?: string | Array<string> | ((informations: Informations) => string | Array<string>);
    });
}
interface FlowObject {
    label: string;
    flow: Flow;
    collapsed: boolean;
}
declare type Flow = Array<string | FlowObject>;
declare type TFunctionalProperty = <T>(entry: string, prop: T | ((param: {
    rawValues: {
        [x: string]: any;
    };
    value: any;
    informations?: Informations;
    error?: {
        [x: string]: any;
    };
}) => T), informations?: Informations, error?: {
    [x: string]: any;
}) => T;
interface Informations {
    path: string;
    key?: string;
    parent?: Informations;
    index?: number;
}
interface StepsOptions {
    addLabel?: string;
}
declare type TBaseObject = {
    [key: string]: any;
};

declare type FormProps<DataType> = {
    schema: Schema;
    flow?: Array<string | FlowObject>;
    value?: DataType;
    inputWrapper?: (props: object) => JSX.Element;
    onSubmit: (obj: DataType) => void;
    onError?: (errors: Object, e?: React$1.BaseSyntheticEvent) => void;
    footer?: (props: {
        reset: () => void;
        valid: () => void;
    }) => JSX.Element;
    className?: string;
    options?: Option;
    ref?: MutableRefObject<FormRef | undefined>;
};
interface FormRef {
    handleSubmit: () => void;
    trigger: () => void;
    methods: UseFormReturn & {
        data: () => any;
    };
}
declare const Form: <T extends TBaseObject>(props: FormProps<T>, ref?: React$1.Ref<FormRef>) => React$1.ReactElement;

export { BooleanInput, CodeInput, Collapse, ConditionnalSchema, ConditionnalSchemaElement, Flow, FlowObject, Form, FormProps, FormRef, Format, HttpClient, Informations, MarkdownInput, ObjectInput, Option, OptionActionItem, OptionActions, Schema, SchemaEntry, SchemaRenderType, SelectInput, SelectOption, SingleLineCode, StepsOptions, TBaseObject, TFunctionalProperty, Type, constraints_d as constraints, format, type };
